==> haskell-quickcheck-classes-0.6.5.0-242-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-InRDmb7TirX15K2sUhT6VL
key:                  quickcheck-classes-0.6.5.0-InRDmb7TirX15K2sUhT6VL
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  d20ea2b0c4c516957ba3b24ce34533b4
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-InRDmb7TirX15K2sUhT6VL
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm base-4.17.2.1 containers-0.6.7
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk
    primitive-addr-0.1.0.2-2XEPJrMw47EKLsYmX6kPX8
    quickcheck-classes-base-0.6.2.0-uW3drZqLLuLOHHOaouKJe
    semigroupoids-6.0.1-4BfowyD1sQLDpGJI2EeKah
    semirings-0.6-BYpt4WkWcIZHx1tJXuBZmN transformers-0.5.6.2
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-classes-0.6.5.0-243-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-classes
version:              0.6.5.0
visibility:           public
id:                   quickcheck-classes-0.6.5.0-Ki6qABPm98vDJ3fzLdhkhu
key:                  quickcheck-classes-0.6.5.0-Ki6qABPm98vDJ3fzLdhkhu
license:              BSD-3-Clause
copyright:            2018 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin, chessai
homepage:             https://github.com/andrewthad/quickcheck-classes#readme
synopsis:             QuickCheck common typeclasses
description:
    This library provides QuickCheck properties to ensure
    that typeclass instances adhere to the set of laws that
    they are supposed to. There are other libraries that do
    similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing
    any new typeclasses that the user needs to learn.

    /Note:/ on GHC < 8.5, this library uses the higher-kinded typeclasses
    ('\''Data.Functor.Classes.Show1'\'', '\''Data.Functor.Classes.Eq1'\'', '\''Data.Functor.Classes.Ord1'\'', etc.),
    but on GHC >= 8.5, it uses `-XQuantifiedConstraints` to express these
    constraints more cleanly.

category:             Testing
abi:                  994727218b0afee569ba702553f9089a
exposed:              True
exposed-modules:
    Test.QuickCheck.Classes Test.QuickCheck.Classes.IsList

hidden-modules:
    Test.QuickCheck.Classes.Alt Test.QuickCheck.Classes.Apply
    Test.QuickCheck.Classes.Euclidean Test.QuickCheck.Classes.Json
    Test.QuickCheck.Classes.MVector Test.QuickCheck.Classes.Plus
    Test.QuickCheck.Classes.Prim Test.QuickCheck.Classes.Semigroupoid
    Test.QuickCheck.Classes.Semiring Test.QuickCheck.Classes.Ring

import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-classes-0.6.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-classes
hs-libraries:         HSquickcheck-classes-0.6.5.0-Ki6qABPm98vDJ3fzLdhkhu
depends:
    QuickCheck-2.14.3-5xMqTFfEVh35pIkOsqqnaD
    aeson-2.1.2.1-LDBL5bcX1HC79scYyh3opi base-4.17.2.1 containers-0.6.7
    primitive-0.8.0.0-KvNzOAcw1vIIZ8l6YzsRlk
    primitive-addr-0.1.0.2-2XEPJrMw47EKLsYmX6kPX8
    quickcheck-classes-base-0.6.2.0-uW3drZqLLuLOHHOaouKJe
    semigroupoids-6.0.1-4tZ3GUdbU6C6aZsHetCI4X
    semirings-0.6-BYpt4WkWcIZHx1tJXuBZmN transformers-0.5.6.2
    vector-0.13.1.0-Dc65CzydytHE52tdajtbOv

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-classes/html/quickcheck-classes.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
